#!/bin/bash
#
# This script is executed only once, immediately after the image
# tarball is unpacked to the app partition (/usr/local).
#

function need_replace {

	old_c=$(cat ${1})
	new_c=$(cat ${2})
	old_v=$(expr match "${old_c}" ".*VERSION=\([0-9]*\)")
	new_v=$(expr match "${new_c}" ".*VERSION=\([0-9]*\)")

	if [ "${old_v}" = "" ]; then
		echo 1
		return
	fi

	if [ ${old_v} -le ${new_v} ]; then
		echo 1
		return
	fi

	echo 0
}

# update ld.so.cache
mount -oremount,rw /
/sbin/ldconfig

if [ ! -d /lib/modules ]; then
	mkdir /lib/modules
fi

if [ ! -f /lib/modules/resetjumper.ko ]; then
	cp /usr/local/modules/resetjumper.ko /lib/modules
fi

if [ ! -c /dev/bfpga ] ; then
	mknod /dev/bfpga c 254 0
fi

if [ ! -c /dev/analog0 ] ; then
    for i in $(seq 0 7) ; do
	mknod /dev/analog$i c 253 $i
    done
fi

# create gsm devices
for gsm_i in `seq 0 3`; do
	gsm_dev="/dev/gsm${gsm_i}"
	if [ ! -c ${gsm_dev} ] ; then
		mknod ${gsm_dev} c 252 ${gsm_i}
	fi
done

# remove libsqlite3 (if installed)
libsqlite3_files="/usr/bin/sqlite3 /usr/lib/libsqlite3.so /usr/lib/libsqlite3.so.0.8.6 /usr/lib/libsqlite3.so.0 /usr/lib/pkgconfig/sqlite3.pc /usr/include/sqlite3.h /usr/include/sqlite3ext.h"
for file in ${libsqlite3_files}; do
	if [ -f ${file} ]; then
		rm -f ${file}
	fi
done

if [ ! -f /usr/lib/mod_auth.so ] ; then
    cp /usr/local/conf/mod_auth.so /usr/lib/
    cp /usr/local/conf/lighttpd.conf /etc/
fi

if [ "$(need_replace "/etc/lighttpd.conf" "/usr/local/conf/lighttpd.conf")" -eq 1 ] ; then
    cp /usr/local/conf/lighttpd.conf /etc/
fi

if [ "$(need_replace "/etc/init.d/S40network" "/usr/local/conf/S40network")" -eq 1 ]; then
    cp /usr/local/conf/S40network /etc/init.d/
fi

if [ "$(need_replace "/usr/sbin/update-time" "/usr/local/conf/update-time")" -eq 1 ] ; then
    cp /usr/local/conf/update-time /usr/sbin/
fi

if [ "$(need_replace "/etc/init.d/S30factorydef" "/usr/local/conf/S30factorydef")" -eq 1 ] ; then
    cp /usr/local/conf/S30factorydef /etc/init.d/
fi

if [ "$(need_replace "/etc/init.d/S50watchdog" "/usr/local/conf/S50watchdog")" -eq 1 ] ; then
    cp /usr/local/conf/S50watchdog /etc/init.d/
fi

if [ "$(need_replace "/etc/init.d/S90app" "/usr/local/conf/S90app")" -eq 1 ] ; then
    cp /usr/local/conf/S90app /etc/init.d/
fi

if [ "$(need_replace "/etc/init.d/S99finishprod" "/usr/local/conf/S99finishprod")" -eq 1 ] ; then
    cp /usr/local/conf/S99finishprod /etc/init.d/
fi

if [ "$(need_replace "/usr/www/cgi-bin/update-tool.php" "/usr/local/conf/update-tool.php")" -eq 1 ] ; then
    cp /usr/local/conf/update-tool.php /usr/www/cgi-bin/
fi

if [ "$(need_replace "/usr/share/udhcpc/default.script" "/usr/local/conf/udhcp-conf.script")" -eq 1 ] ; then
    cp /usr/local/conf/udhcp-conf.script /usr/share/udhcpc/default.script
fi

if [ "$(need_replace "/usr/conf/snmpd_berofix.conf" "/usr/local/conf/snmpd_berofix.conf")" -eq 1 ] ; then
    cp /usr/local/conf/snmpd_berofix.conf /usr/conf/snmpd_berofix.conf
fi

if [ "$(need_replace "/etc/php.ini" "/usr/local/conf/php.ini")" -eq 1 ] ; then
    cp /usr/local/conf/php.ini /etc/
fi

# check if fallback scripts need to be updated
if [ "$(need_replace "/usr/fallback/beroConf.php" "/usr/local/php/beroConf.php")" -eq 1 ] ; then
    cp /usr/local/php/beroConf.php /usr/fallback/
fi

if [ "$(need_replace "/usr/fallback/beroconf" "/usr/local/bin/beroconf")" -eq 1 ] ; then
    cp /usr/local/bin/beroconf /usr/fallback/
fi

if [ "$(need_replace "/usr/fallback/beroconf.bin" "/usr/local/php/beroconf.bin")" -eq 1 ] ; then
    cp /usr/local/php/beroconf.bin /usr/fallback/
fi

if [ "$(need_replace "/usr/fallback/install.sh" "/usr/local/sbin/install.sh")" -eq 1 ] ; then
    cp /usr/local/sbin/install.sh /usr/fallback/
fi

if [ "$(need_replace "/usr/fallback/update-interfaces" "/usr/local/sbin/update-interfaces")" -eq 1 ] ; then
    cp /usr/local/sbin/update-interfaces /usr/fallback/
fi

if [ "$(need_replace "/usr/fallback/update-interfaces.bin" "/usr/local/php/update-interfaces.bin")" -eq 1 ] ; then
    cp /usr/local/php/update-interfaces.bin /usr/fallback/
fi

if [ "$(need_replace "/usr/fallback/update-network" "/usr/local/sbin/update-network")" -eq 1 ] ; then
    cp /usr/local/sbin/update-network /usr/fallback/
fi


bftype=$(sed "s/.*carduuid=//" /proc/cmdline | sed "s/ revision.*//"  | cut -d "-" -f2)

if [ "$bftype" = "64" ] ; then
        if [ -c /dev/ttyS0 ] ; then
                mv /dev/ttyS0 /dev/ttyS0_off
        fi
fi

# set up new user-appfs-user
if [ ! -d /home/admin ]; then
	echo "admin:x:1001:1001:admin:/home/admin:/bin/bash" >> /etc/passwd
	echo "admin:$1$$CoERg7ynjYLsj2j4glJ34.:10933:0:99999:7:::" >> /etc/shadow
	addgroup -g 1001 admin

	mkdir /home/admin
	chown admin:admin /home/admin

	umount /mnt/images
	rm -rf /mnt/images
	ln -s /tmp/ /mnt/images

	cp /etc/fstab /etc/fstab_orig
	sed -e 's/\/mnt\/images    jffs2    rw,defaults/\/home\/admin    jffs2    ro,defaults,user=admin/' /etc/fstab_orig > /etc/fstab
	rm -f /etc/fstab_orig

	mount /home/admin -orw
	rm -rf $(ls -A /home/admin)
	echo -e "export PATH=/bin:/usr/bin:/usr/local/bin:/home/admin/bin\n\nif [ -f ~/.bashrc ]; then\n\tsource ~/.bashrc\nfi" > /home/admin/.bash_profile
	chown admin:admin /home/admin/.bash_profile
	chmod 0644 /home/admin/.bash_profile
	sync
	sleep 1
	mount /home/admin -oremount,ro
fi

if [ "$(need_replace "/etc/init.d/S91userapp" "/usr/local/conf/S91userapp")" -eq 1 ] ; then
    cp /usr/local/conf/S91userapp /etc/init.d/
fi

if [ "$(need_replace "/usr/www/index.php" "/usr/local/conf/root_index.php")" -eq 1 ] ; then
    cp /usr/local/conf/root_index.php /usr/www/index.php
fi


mount -oremount,ro /


if [ ! -d /usr/local/www/api ] ; then
    mkdir -p /usr/local/www/api
fi

if [ ! -f /usr/conf/apiusers.conf ] ; then
    echo "admin:admin" > /usr/conf/apiusers.conf
fi

if [ ! -f /usr/conf/isgw.tones ] ; then
	cp /usr/local/conf/isgw.tones /usr/conf
fi

if [ ! -f /usr/conf/isgw.causes ] ; then
	cp /usr/local/conf/isgw.causes /usr/conf
fi


if [ -f /usr/conf/isdn.conf ] ; then
#migrating from 1.0 to 2.0 Version
    mv /usr/conf/isdn.conf /usr/conf/hardware.conf
    rm /usr/conf/ari.db
    /usr/bin/env -i bash -c "/usr/bin/php-cgi /usr/local/www/berogui/includes/migration.php > /dev/null"
fi

MTU=$(/usr/local/bin/beroconf get root lan-mtu)
if [ "$MTU" = "500" ] ; then
        /usr/local/bin/beroconf set root lan-mtu 1500
fi


/usr/bin/env -i bash -c "/usr/bin/php-cgi /usr/local/www/berogui/includes/create_files.php  > /dev/null"

